Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code

Unified Diff: mobile/android/base/java/org/mozilla/gecko/GeckoApplication.java

Issue 29863604: Issue 6865 - Update ABP dependency to version 3.2 (Closed)
Patch Set: Adjusting code style Created Jan. 16, 2019, 1:45 p.m.
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: mobile/android/base/java/org/mozilla/gecko/GeckoApplication.java
===================================================================
--- a/mobile/android/base/java/org/mozilla/gecko/GeckoApplication.java
+++ b/mobile/android/base/java/org/mozilla/gecko/GeckoApplication.java
@@ -308,20 +308,20 @@
null);
EventDispatcher.getInstance().registerBackgroundThreadListener(mListener,
"PushServiceAndroidGCM:Configure",
"Bookmark:Insert",
"Image:SetAs",
"Profile:Create",
null);
// Added AddOnBridge initialisation here for resending requests that for some reason,
// couldn't be saved by the extension
// See https://issues.adblockplus.org/ticket/2853
- org.adblockplus.browser.AddOnBridge.init(context);
+ org.adblockplus.browser.ExtensionBridge.init(context);
super.onCreate();
}
/**
@@ -308,20 +308,20 @@
"Profile:Create",
null);
- // Added AddOnBridge initialisation here for resending requests that for some reason,
+ // Added ExtensionBridge initialisation here for resending requests that for some reason,
// couldn't be saved by the extension
// See https://issues.adblockplus.org/ticket/2853
* May be called when a new GeckoApplication object
* replaces an old one due to assets change.
*/

Powered by Google App Engine
This is Rietveld